@@ -119,7 +119,7 @@ void DataDeviceInterfacePrivate::data_device_start_drag(Resource *resource, wl_r
     }
     surface = focusSurface;
     drag.serial = serial;
-    emit q->dragStarted();
+    Q_EMIT q->dragStarted();
 }
 
 void DataDeviceInterfacePrivate::data_device_set_selection(Resource *resource, wl_resource *source, uint32_t serial)
@@ -141,9 +141,9 @@ void DataDeviceInterfacePrivate::data_device_set_selection(Resource *resource, w
     }
     selection = dataSource;
     if (selection) {
-        emit q->selectionChanged(selection);
+        Q_EMIT q->selectionChanged(selection);
     } else {
-        emit q->selectionCleared();
+        Q_EMIT q->selectionCleared();
     }
 }
 
@@ -175,7 +175,7 @@ DataOfferInterface *DataDeviceInterfacePrivate::createDataOffer(AbstractDataSour
 void DataDeviceInterfacePrivate::data_device_destroy_resource(QtWaylandServer::wl_data_device::Resource *resource)
 {
     Q_UNUSED(resource)
-    emit q->aboutToBeDestroyed();
+    Q_EMIT q->aboutToBeDestroyed();
     delete q;
 }
 
@@ -183,7 +183,8 @@ DataDeviceInterface::DataDeviceInterface(SeatInterface *seat, wl_resource *resou
     : QObject(nullptr)
     , d(new DataDeviceInterfacePrivate(seat, this, resource))
 {
-    seat->d_func()->registerDataDevice(this);
+    SeatInterfacePrivate *seatPrivate = SeatInterfacePrivate::get(seat);
+    seatPrivate->registerDataDevice(this);
 }
 
 DataDeviceInterface::~DataDeviceInterface() = default;
@@ -263,8 +264,9 @@ void DataDeviceInterface::updateDragTarget(SurfaceInterface *surface, quint32 se
         }
         // don't update serial, we need it
     }
-    if (!surface) {
-        if (auto s = d->seat->dragSource()->dragSource()) {
+    auto dragSourceDevice = d->seat->dragSource();
+    if (!surface || !dragSourceDevice) {
+        if (auto s = dragSourceDevice->dragSource()) {
             s->dndAction(DataDeviceManagerInterface::DnDAction::None);
         }
         return;
@@ -274,7 +276,7 @@ void DataDeviceInterface::updateDragTarget(SurfaceInterface *surface, quint32 se
         // TODO: do this for all client's surfaces?
         return;
     }
-    auto *source = d->seat->dragSource()->dragSource();
+    auto *source = dragSourceDevice->dragSource();
     if (source) {
         source->setAccepted(false);
     }
